@@ -12,8 +12,7 @@ from datetime import datetime, timedelta
 from typing import List
 from tqdm import tqdm
 
-from ..analyze import CzscTrader, RawBar, KlineGenerator
-from ..signals.signals import get_default_signals
+from ..analyze import RawBar
 from ..enum import Freq
 from ..utils.cache import home_path
 
@@ -147,60 +146,3 @@ def get_ths_members(exchange="A"):
     res_df = pd.concat(res, ignore_index=True)
     return res_df
 
-def get_init_kg(ts_code: str,
-                end_dt: [str, datetime] = None,
-                max_count: int = 3000,
-                generator: [KlineGenerator] = KlineGenerator,
-                freqs=('1分钟', '5分钟', '15分钟', '30分钟', '60分钟', '日线'),
-                asset: str = 'E',
-                fq='qfq'):
-    """获取 ts_code 的初始化 kline generator"""
-    if end_dt:
-        end_dt = pd.to_datetime(end_dt)
-    else:
-        end_dt = datetime.now()
-
-    last_day = (end_dt - timedelta(days=1)).replace(hour=16, minute=0)
-
-    kg = generator(max_count=max_count, freqs=freqs)
-
-    for freq in freqs:
-        if freq == Freq.F1.value:
-            start_dt = end_dt - timedelta(days=21)
-        elif freq == Freq.F5.value:
-            start_dt = end_dt - timedelta(days=21*5)
-        elif freq == Freq.F15.value:
-            start_dt = end_dt - timedelta(days=21*15)
-        elif freq == Freq.F30.value:
-            start_dt = end_dt - timedelta(days=500)
-        elif freq == Freq.F60.value:
-            start_dt = end_dt - timedelta(days=1000)
-        elif freq == Freq.D.value:
-            start_dt = end_dt - timedelta(days=1500)
-        else:
-            raise ValueError(freq.value)
-
-        bars = get_kline(ts_code=ts_code, asset=asset, start_date=start_dt, end_date=last_day,
-                         freq=freq_cn_map[freq], fq=fq)
-        kg.init_kline(freq, bars)
-        print(f"{ts_code} - {freq} - bars_len: {len(bars)} - kg_last_dt: "
-              f"{kg.get_kline(freq, 1)[-1].dt} - last_day: {last_day}")
-
-    bars = get_kline(ts_code=ts_code, asset=asset, start_date=last_day, end_date=end_dt, freq=Freq.F1, fq=fq)
-    data = [x for x in bars if x.dt > last_day]
-
-    if data:
-        print(f"{ts_code}: 更新 kg 至 {end_dt.strftime(dt_fmt)}，共有{len(data)}行数据需要update")
-        for row in data:
-            kg.update(row)
-    return kg
-
-
-class TsCzscTrader(CzscTrader):
-    def __init__(self, ts_code, end_dt=None, max_count=2000, asset='E',
-                 freqs=('1分钟', '5分钟', '15分钟', '30分钟', '60分钟', '日线')):
-        self.ts_code = ts_code
-        self.asset = asset
-        kg = get_init_kg(ts_code, end_dt, asset=asset, max_count=max_count, freqs=freqs)
-        super(TsCzscTrader, self).__init__(kg, get_signals=get_default_signals, events=[])
-
