@@ -52,7 +52,7 @@ class TsDataCache:
         self.api_names = [
             'ths_daily', 'ths_index', 'ths_member', 'pro_bar',
             'hk_hold', 'cctv_news', 'daily_basic', 'index_weight',
-            'adj_factor', 'pro_bar_minutes'
+            'adj_factor', 'pro_bar_minutes', 'limit_list'
         ]
         self.api_path_map = {k: os.path.join(cache_path, k) for k in self.api_names}
 
@@ -84,7 +84,7 @@ class TsDataCache:
                                   fields='ts_code,trade_date,open,close,high,low,vol')
             kline = kline.sort_values('trade_date', ignore_index=True)
 
-            for bar_number in (1, 2, 3, 5, 10, 20):
+            for bar_number in (1, 2, 3, 5, 8, 13, 21, 34, 55, 89, 144, 233, 377):
                 # 向后看
                 n_col_name = 'n' + str(bar_number) + 'b'
                 kline[n_col_name] = (kline['close'].shift(-bar_number) / kline['close'] - 1) * 10000
@@ -167,7 +167,7 @@ class TsDataCache:
             kline = kline.sort_values('trade_date', ignore_index=True)
             kline['trade_date'] = pd.to_datetime(kline['trade_date'], format=self.date_fmt)
 
-            for bar_number in (1, 2, 3, 5, 10, 20):
+            for bar_number in (1, 2, 3, 5, 8, 13, 21, 34, 55, 89, 144, 233, 377):
                 # 向后看
                 n_col_name = 'n' + str(bar_number) + 'b'
                 kline[n_col_name] = (kline['close'].shift(-bar_number) / kline['close'] - 1) * 10000
@@ -261,7 +261,7 @@ class TsDataCache:
                 for col in ['open', 'close', 'high', 'low']:
                     kline[col] = kline.apply(lambda x: x[col] * adj_map[x['trade_date']], axis=1)
 
-            for bar_number in (1, 2, 3, 5, 10, 20):
+            for bar_number in (1, 2, 3, 5, 8, 13, 21, 34, 55, 89, 144, 233, 377):
                 # 向后看
                 n_col_name = 'n' + str(bar_number) + 'b'
                 kline[n_col_name] = (kline['close'].shift(-bar_number) / kline['close'] - 1) * 10000
@@ -392,6 +392,23 @@ class TsDataCache:
             io.save_pkl(df, file_cache)
         return df
 
+    def limit_list(self, trade_date: str):
+        """https://tushare.pro/document/2?doc_id=198
+
+        :param trade_date: 交易日期
+        :return: 每日涨跌停统计
+        """
+        trade_date = pd.to_datetime(trade_date).strftime("%Y%m%d")
+        cache_path = self.api_path_map['limit_list']
+        file_cache = os.path.join(cache_path, f"limit_list_{trade_date}.pkl")
+
+        if os.path.exists(file_cache):
+            df = io.read_pkl(file_cache)
+        else:
+            df = pro.limit_list(trade_date=trade_date)
+            io.save_pkl(df, file_cache)
+        return df
+
     # ------------------------------------CZSC 加工接口----------------------------------------------
 
     def get_all_ths_members(self, exchange="A", type_="N"):
